# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## [0.4.0] - 2020-02-26
### Removed
- remove a dependency

## [0.3.1] - 2019-09-30
### Added
- configurable settings path
- test by test result

## [0.3.0] - 2019-09-24
### Added
- database tests

## [0.2.1] - 2019-09-24
### Fixed
- connection issue

## [0.2.0] - 2019-09-24
### Added
- database migrations

## [0.1.0] - 2019-09-18
### Added
- initial project structure
